==> spread-5.0.0.54-py3-none-any.whl: spread_dashboard/static/report/light.js <==
var stack = $(document).find('.engineries form');
var currentIndex = 0;
var startTime;
var endTime;
var totalConsumption = 0;

const client = init_client(
    broker,
    function onConnect() {
        console.log('MQTT Connected');
        client.subscribe(broker.reply);
    },
    function onMessage(topic, message) {
        if (message.value && message.value.data) {
            const eng = document.getElementById(message.key);
            const consumption = parseFloat(message.value.data.value);

            updateProgress(parseInt(currentIndex / stack.length * 100));

            const $loc = $(document.getElementById($(eng).find(' form')[0].location.value));
            if (!isNaN(consumption)) {
                totalConsumption += consumption;

                if (message.value.data.hasOwnProperty('value')) {
                    $(eng).find('.consumption').each(function (i, node) {
                        $(node)[0].textContent = consumption.toFixed(2);
                    });
                }
                if (message.value.data.hasOwnProperty('workTime')) {
                    $(eng).find('.work-time').each(function (i, node) {
                        $(node)[0].textContent = (message.value.data.workTime / 1000 / 60 / 60).toFixed(1);
                    });
                }

                $loc.find('.summ').each(function(i, node) {
                    var value = parseFloat(node.textContent);
                    if (isNaN(value)) value = 0;
                    node.textContent = (value + consumption).toFixed(2);
                });
                $loc.find('.badge').each(function (i, node) { updateBadge(node, consumption); return false;});

                $loc.parents('.panel').each(function (i, node) {
                    $(node).find('.badge').each(function (i, node) { updateBadge(node, consumption); return false;});
                });
            }
            request();
        }
    }
);

const now = new Date();
$(document).find('input[name=timeFrom]').each(function (i, node) {
    node.value = now.toISOString().substr(0, 8) + '01';
});
$(document).find('input[name=timeTo]').each(function (i, node) {
    node.value = now.toISOString().substr(0, 10);
});

$(document).on('click', '.panel-heading', function () {
    $(this).parents('.panel-collapsed').each(function () {
        $(this).find('i').each(function () {
            $(this).toggleClass('glyphicon-chevron-down').toggleClass('glyphicon-chevron-up');
            return false;
        });
        $(this).find('.panel-body').each(function () {
            $(this).slideToggle();
            return false;
        });
        return false;
    });
});

function getReport(t1, t2) {
    if (currentIndex !== 0) {
        alert('Предыдущий запрос еще не закончен!');
    }
    else {
        startTime = t1 + 'T00:00:00';
        endTime = t2 + 'T23:59:59';
        console.log(t1 + '' + t2);
        function clear(i, node) {node.textContent = '-';}
        $(document).find('.engineries .consumption').each(clear);
        $(document).find('.engineries .work-time').each(clear);
        $(document).find('.badge').each(function(i, node) { updateBadge(node)});
        $(document).find('.engineries .summ').each(function(i, node) { node.textContent = '-'; });
        $(document).find(' form input[name=download]').hide();
        currentIndex = 0;
        totalConsumption = 0;
        request();
    }
    return false;
}

function request() {
    if (currentIndex < stack.length) {
        const form = stack[currentIndex++];
        console.log(form.renew.value);
        client.send(form.renew.value, JSON.stringify({
            params: {
                algorithm: "integral",
                startTime: startTime,
                endTime: endTime,
            },
            key: form.id.value,
            session: broker.guid
        }));
    } else {
        currentIndex = 0;
        $(document).find(' form input[name=download]').show();
    }
}

function updateProgress(value) {
    $('.progress-bar').css('width', value+'%')
        .attr('aria-valuenow', value)[0]
        .textContent = value === 100 ? 'Готово!' : value + '%';
}

function updateBadge(node, consumption) {
    var value;
    if (isNaN(consumption)) {
        $(node).addClass('empty');
        consumption = 0;
    } else {
        $(node).removeClass('empty');
        value = parseFloat(node.getAttribute('value'));
    }
    if (isNaN(value)) {
        value = 0;
    }
    value += consumption;
    node.setAttribute('value', value);
    node.textContent = (value / 1000).toFixed(1) + ' кВт*ч';
}

function downloadReport() {
    var uri = 'data:application/vnd.ms-excel;base64,'
        , template = '<html xmlns:o="urn:schemas-microsoft-com:office:office" xmlns:x="urn:schemas-microsoft-com:office:excel" xmlns="http://www.w3.org/TR/REC-html40"><head><!--[if gte mso 9]><xml><x:ExcelWorkbook><x:ExcelWorksheets><x:ExcelWorksheet><x:Name>{worksheet}</x:Name><x:WorksheetOptions><x:DisplayGridlines/></x:WorksheetOptions></x:ExcelWorksheet></x:ExcelWorksheets></x:ExcelWorkbook></xml><![endif]--></head><body><table><tbody>{table}</tbody></table></body></html>'
        , base64 = function(s) { return window.btoa(unescape(encodeURIComponent(s))) }
        , format = function(s, c) {
        return s.replace(/{(\w+)}/g, function(m, p) { return c[p]; })
    }
        , downloadURI = function(uri, name) {
        var link = document.createElement("a");
        link.download = name;
        link.href = uri;
        link.click();
    };

    var ctx = {worksheet: 'Worksheet', table: ''};
    $(document).find('.engineries').each(function (index, node) {
        const locName = $(node).find(' input[name=location-name]')[0].value;
        var inner = node.innerHTML
            .replace('<tbody>', '')
            .replace('</tbody>', '')
            .replace('</tr>', '</tr>\n' +
                '    <tr>\n' +
                '        <td>' + locName + '</td>\n' +
                '    </tr>\n')
            .replace('<th class="offset-right"></th>', '<th></th>\n        <th></th>')
            .replace('<th>Итого:</th>','<th></th>')
            .replace('<th hidden=""></th>','<td>Итого (' + locName + '):</td>')
            .split(/(?<=\d)\.(?=\d)/).join(',')
            .split(/\s\w+(?<!colspan)=".*"/).join('')
            .split(/<input.*>/).join('')
            .split(/<form.+\/form>/).join('')
            .split(/\n\s+\n/).join('\n');
        if (index === 0) {
            ctx.table += inner
        } else {
            ctx.table += inner.substr(inner.indexOf('</tr>')+ 5);
        }
        ctx.table += '    <tr></tr>'
    });
    ctx.table +=
        '<tr>\n' +
        '    <th colspan="4">Общий итог:</th>\n' +
        '    <th></th>\n' +
        '    <th></th>\n' +
        '    <th>' + totalConsumption.toFixed(2).replace('.', ',') + '</th>\n' +
        '</tr>\n';
    const resuri = uri + base64(format(template, ctx));
    const fileName =
        projectName
        + ' c ' + startTime.substr(0, 10)
        + ' по ' + endTime.substr(0, 10)
        + ' включительно.xls';

    console.log(fileName);

    downloadURI(resuri, fileName);
}

==> spread-5.3.0.5-py3-none-any.whl: spread_dashboard/static/report/light.js <==
var stack = $(document).find('.engineries form');
var currentIndex = 0;
var startTime;
var endTime;
var totalConsumption = 0;

const client = init_client(
    broker,
    function onConnect() {
        console.log('MQTT Connected');
        client.subscribe(broker['reply'] + broker['guid'], {});
    },
    function onMessage(topic, message) {
        if (message.value && message.value.data) {
            const eng = document.getElementById(message.key);
            const consumption = parseFloat(message.value.data.value);

            updateProgress(parseInt(currentIndex / stack.length * 100));

            const $loc = $(document.getElementById($(eng).find(' form')[0].location.value));
            if (!isNaN(consumption)) {
                totalConsumption += consumption;

                if (message.value.data.hasOwnProperty('value')) {
                    $(eng).find('.consumption').each(function (i, node) {
                        $(node)[0].textContent = consumption.toFixed(2);
                    });
                }
                if (message.value.data.hasOwnProperty('workTime')) {
                    $(eng).find('.work-time').each(function (i, node) {
                        $(node)[0].textContent = (message.value.data.workTime / 1000 / 60 / 60).toFixed(1);
                    });
                }

                $loc.find('.summ').each(function(i, node) {
                    var value = parseFloat(node.textContent);
                    if (isNaN(value)) value = 0;
                    node.textContent = (value + consumption).toFixed(2);
                });
                $loc.find('.badge').each(function (i, node) { updateBadge(node, consumption); return false;});

                $loc.parents('.panel').each(function (i, node) {
                    $(node).find('.badge').each(function (i, node) { updateBadge(node, consumption); return false;});
                });
            }
            request();
        }
    }
);

const now = new Date();
$(document).find('input[name=timeFrom]').each(function (i, node) {
    node.value = now.toISOString().substr(0, 8) + '01';
});
$(document).find('input[name=timeTo]').each(function (i, node) {
    node.value = now.toISOString().substr(0, 10);
});

$(document).on('click', '.panel-heading', function () {
    $(this).parents('.panel-collapsed').each(function () {
        $(this).find('i').each(function () {
            $(this).toggleClass('glyphicon-chevron-down').toggleClass('glyphicon-chevron-up');
            return false;
        });
        $(this).find('.panel-body').each(function () {
            $(this).slideToggle();
            return false;
        });
        return false;
    });
});

function getReport(t1, t2) {
    if (currentIndex !== 0) {
        alert(gettext('report_double_query'));
    }
    else {
        startTime = t1 + 'T00:00:00';
        endTime = t2 + 'T23:59:59';
        console.log(t1 + '' + t2);
        function clear(i, node) {node.textContent = '-';}
        $(document).find('.engineries .consumption').each(clear);
        $(document).find('.engineries .work-time').each(clear);
        $(document).find('.badge').each(function(i, node) { updateBadge(node)});
        $(document).find('.engineries .summ').each(function(i, node) { node.textContent = '-'; });
        $(document).find(' form input[name=download]').hide();
        currentIndex = 0;
        totalConsumption = 0;
        request();
    }
    return false;
}

function request() {
    if (currentIndex < stack.length) {
        const form = stack[currentIndex++];
        console.log(form.renew.value);
        client.send(form.renew.value, JSON.stringify({
            params: {
                algorithm: "integral",
                startTime: startTime,
                endTime: endTime,
            },
            key: form.id.value,
            session: broker.guid
        }));
    } else {
        currentIndex = 0;
        $(document).find(' form input[name=download]').show();
    }
}

function updateProgress(value) {
    $('.progress-bar').css('width', value+'%')
        .attr('aria-valuenow', value)[0]
        .textContent = value === 100 ? gettext('report_complete') : value + '%';
}

function updateBadge(node, consumption) {
    var value;
    if (isNaN(consumption)) {
        $(node).addClass('empty');
        consumption = 0;
    } else {
        $(node).removeClass('empty');
        value = parseFloat(node.getAttribute('value'));
    }
    if (isNaN(value)) {
        value = 0;
    }
    value += consumption;
    node.setAttribute('value', value);
    node.textContent = (value / 1000).toFixed(1) + ' ' + gettext('report_energy_unit');
}

function downloadReport() {
    var uri = 'data:application/vnd.ms-excel;base64,'
        , template = '<html xmlns:o="urn:schemas-microsoft-com:office:office" xmlns:x="urn:schemas-microsoft-com:office:excel" xmlns="http://www.w3.org/TR/REC-html40"><head><!--[if gte mso 9]><xml><x:ExcelWorkbook><x:ExcelWorksheets><x:ExcelWorksheet><x:Name>{worksheet}</x:Name><x:WorksheetOptions><x:DisplayGridlines/></x:WorksheetOptions></x:ExcelWorksheet></x:ExcelWorksheets></x:ExcelWorkbook></xml><![endif]--></head><body><table><tbody>{table}</tbody></table></body></html>'
        , base64 = function(s) { return window.btoa(unescape(encodeURIComponent(s))) }
        , format = function(s, c) {
        return s.replace(/{(\w+)}/g, function(m, p) { return c[p]; })
    }
        , downloadURI = function(uri, name) {
        var link = document.createElement("a");
        link.download = name;
        link.href = uri;
        link.click();
    };

    var ctx = {worksheet: 'Worksheet', table: ''};
    $(document).find('.engineries').each(function (index, node) {
        const locName = $(node).find(' input[name=location-name]')[0].value;
        var inner = node.innerHTML
            .replace('<tbody>', '')
            .replace('</tbody>', '')
            .replace('</tr>', '</tr>\n' +
                '    <tr>\n' +
                '        <td>' + locName + '</td>\n' +
                '    </tr>\n')
            .replace('<th class="offset-right"></th>', '<th></th>\n        <th></th>')
            .replace('<th>' + gettext('report_total') + ':</th>','<th></th>')
            .replace('<th hidden=""></th>','<td>' + gettext('report_total') + '(' + locName + '):</td>')
            .split(/(?<=\d)\.(?=\d)/).join(',')
            .split(/\s\w+(?<!colspan)=".*"/).join('')
            .split(/<input.*>/).join('')
            .split(/<form.+\/form>/).join('')
            .split(/\n\s+\n/).join('\n');
        if (index === 0) {
            ctx.table += inner
        } else {
            ctx.table += inner.substr(inner.indexOf('</tr>')+ 5);
        }
        ctx.table += '    <tr></tr>'
    });
    ctx.table +=
        '<tr>\n' +
        '    <th colspan="4">' + gettext('report_result') + ':</th>\n' +
        '    <th></th>\n' +
        '    <th></th>\n' +
        '    <th>' + totalConsumption.toFixed(2).replace('.', ',') + '</th>\n' +
        '</tr>\n';
    const resuri = uri + base64(format(template, ctx));
    const fileName =
        projectName
        + ' [' + startTime.substr(0, 10)
        + '_' + endTime.substr(0, 10)
        + ']' + '.xls';

    console.log(fileName);

    downloadURI(resuri, fileName);
}
